/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_jKlKujQK);
  numBytes += sPhasor_k_init(&sPhasor_ihNFaTFW, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_JHBzkgsN);
  numBytes += sRPole_init(&sRPole_JrJKwUh7);
  numBytes += sRPole_init(&sRPole_jC5h0ehw);
  numBytes += sTabhead_init(&sTabhead_n9kM1Rv0, &hTable_SJPP0jY5);
  numBytes += sTabread_init(&sTabread_rXSyAOQQ, &hTable_SJPP0jY5, false);
  numBytes += sTabread_init(&sTabread_cm34hrOX, &hTable_SJPP0jY5, false);
  numBytes += sLine_init(&sLine_3W5cgtK1);
  numBytes += sTabhead_init(&sTabhead_cjdlhU1z, &hTable_gqfhwwMa);
  numBytes += sTabread_init(&sTabread_FnUAZHjk, &hTable_gqfhwwMa, false);
  numBytes += sTabread_init(&sTabread_dzvBNNPx, &hTable_gqfhwwMa, false);
  numBytes += sLine_init(&sLine_5eABCtkg);
  numBytes += sTabwrite_init(&sTabwrite_SqNAgmdu, &hTable_gqfhwwMa);
  numBytes += sTabwrite_init(&sTabwrite_AzuyurUd, &hTable_SJPP0jY5);
  numBytes += cVar_init_f(&cVar_vWnEMdls, 0.0f);
  numBytes += cVar_init_f(&cVar_ZA34fhpF, 0.0f);
  numBytes += cVar_init_f(&cVar_iwKN9Wh6, 0.0f);
  numBytes += cVar_init_f(&cVar_S6NnOoKo, 0.0f);
  numBytes += cVar_init_s(&cVar_O2n6abgG, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_rJXyaNun, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HR2Yf9JS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_40GqeZgQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_V11cei7y, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_EHBhblFB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zXHKrpGf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F21hf3A6, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_kZvEAUle, 0.0f);
  numBytes += cDelay_init(this, &cDelay_HtKLzZ16, 0.0f);
  numBytes += hTable_init(&hTable_gqfhwwMa, 256);
  numBytes += cDelay_init(this, &cDelay_YJwCduGc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_npGpczk7, 0.0f);
  numBytes += hTable_init(&hTable_SJPP0jY5, 256);
  numBytes += cVar_init_f(&cVar_XyDdSqsH, 14.0f);
  numBytes += cBinop_init(&cBinop_ZmKZGD45, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VW5AzXvf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8hFKzdBb, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FcPWS2dl, 14.0f);
  numBytes += cBinop_init(&cBinop_e2jn9pry, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pKkuoUfc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qWDMUlP1, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_JBBu7BCc, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_CxFOUKH3, 1, -1);
  numBytes += cVar_init_f(&cVar_qXypSg6d, 0.2f);
  numBytes += cSlice_init(&cSlice_CZrkJwSC, 1, -1);
  numBytes += cVar_init_f(&cVar_EaHdqc4a, 0.0f);
  numBytes += cSlice_init(&cSlice_16IG6Mo5, 1, -1);
  numBytes += cVar_init_f(&cVar_L9bfNIiK, 2.0f);
  numBytes += cSlice_init(&cSlice_XlCwbQZC, 1, -1);
  numBytes += cVar_init_f(&cVar_vqiiV6LL, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_gqfhwwMa);
  hTable_free(&hTable_SJPP0jY5);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_gqfhwwMa; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_SJPP0jY5; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MbEGMGXr_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_puikHvkw_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O7GSDneY_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MdFUowkC_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6AEv2Adu_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PJXvHGDj_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lwQTCyBs_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R0N9M0wg_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1mO0JhpA_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_vWnEMdls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pdYc55mv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_ZA34fhpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qWxHbBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_iwKN9Wh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_roD6KZpS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_S6NnOoKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FYzJstVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_ti4WaXQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yQuok5Wc_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yQuok5Wc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_ihNFaTFW, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_K261rj3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cF4YNxml_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_cF4YNxml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_i7VJaZAw_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_O2n6abgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PBK45go3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_tvP3tKiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GRlIrUTu_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rJXyaNun, m);
}

void Heavy_WSTD_FLANGR::cBinop_i7VJaZAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HR2Yf9JS, m);
}

void Heavy_WSTD_FLANGR::cMsg_PBK45go3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tvP3tKiq_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GRlIrUTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_40GqeZgQ, m);
}

void Heavy_WSTD_FLANGR::cMsg_DOD0gNXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_edVWNgNB_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_edVWNgNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wwWmo08h_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_V11cei7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FGqP7kuE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_D7c3Cr1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_M3TQC8Ud_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EHBhblFB, m);
}

void Heavy_WSTD_FLANGR::cBinop_wwWmo08h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zXHKrpGf, m);
}

void Heavy_WSTD_FLANGR::cMsg_FGqP7kuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_D7c3Cr1N_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_M3TQC8Ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_F21hf3A6, m);
}

void Heavy_WSTD_FLANGR::cBinop_mUOG4Zqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lJma5Kvj_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_lJma5Kvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NJH6bO3f_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_Nmim9RxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K6vR6OkR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_CxbcunPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6pVYuRyO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_NJH6bO3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qnsIxo7I_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_qnsIxo7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CWZCgw75_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0M6fvIAK_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_CWZCgw75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Sq84qsoY_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_0M6fvIAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZkEDnuOi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Sq84qsoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9awFefHr_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ZkEDnuOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Yf76ZvZ4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Yf76ZvZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zfG2bnYz_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9awFefHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Nmim9RxS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_zfG2bnYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_CxbcunPa_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_FRkyREIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7IdjqlmA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_7IdjqlmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HaRvsX3D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_aIJurtkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IcFWsYOD_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_IcFWsYOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EyzR4Oie_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_kZvEAUle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kZvEAUle, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HtKLzZ16, 0, m, &cDelay_HtKLzZ16_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kZvEAUle, 0, m, &cDelay_kZvEAUle_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SqNAgmdu, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_HtKLzZ16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HtKLzZ16, m);
  cMsg_UTxl5Xvx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_8pRosjHF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_x8OAOoBK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_daBFACUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1gt1S5B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_gqfhwwMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MBppZNTU_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kZvEAUle, 2, m, &cDelay_kZvEAUle_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vV6RYwH3_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_r1gt1S5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_gqfhwwMa, 0, m, &hTable_gqfhwwMa_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_EyzR4Oie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_daBFACUT_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_UTxl5Xvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_gqfhwwMa, 0, m, &hTable_gqfhwwMa_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_vV6RYwH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kZvEAUle, 0, m, &cDelay_kZvEAUle_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_MBppZNTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_HtKLzZ16, 2, m, &cDelay_HtKLzZ16_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_x8OAOoBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SqNAgmdu, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_LaSK3rI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JdtNb23D_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_JdtNb23D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_APaWWFy2_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_YJwCduGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YJwCduGc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_npGpczk7, 0, m, &cDelay_npGpczk7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YJwCduGc, 0, m, &cDelay_YJwCduGc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AzuyurUd, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_npGpczk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_npGpczk7, m);
  cMsg_sjryIKbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_wTDWQ7vO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_szwGZEV7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_3HnSoCl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xu9KkPJp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_SJPP0jY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nPkbwlNc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YJwCduGc, 2, m, &cDelay_YJwCduGc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qGdWRgk6_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Xu9KkPJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SJPP0jY5, 0, m, &hTable_SJPP0jY5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_APaWWFy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_3HnSoCl8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_sjryIKbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SJPP0jY5, 0, m, &hTable_SJPP0jY5_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_qGdWRgk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YJwCduGc, 0, m, &cDelay_YJwCduGc_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_nPkbwlNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_npGpczk7, 2, m, &cDelay_npGpczk7_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_szwGZEV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AzuyurUd, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_XyDdSqsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmKZGD45, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZmKZGD45_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_1SsAd8j3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_H8dTisrh_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_H8dTisrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rZKEPQHJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_ZmKZGD45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dsTkxPBl_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_3Qt1azGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmKZGD45, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZmKZGD45_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_rZKEPQHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3Qt1azGW_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_dsTkxPBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FXObQYKV_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_FXObQYKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ioWjoHgp_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8hFKzdBb, m);
}

void Heavy_WSTD_FLANGR::cBinop_ioWjoHgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VW5AzXvf, m);
}

void Heavy_WSTD_FLANGR::cVar_FcPWS2dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e2jn9pry, HV_BINOP_MULTIPLY, 0, m, &cBinop_e2jn9pry_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_GKug0zQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_F90pXBAu_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_F90pXBAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ypFR7Q2l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_e2jn9pry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CtQ6vPtV_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_X3VN1XMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e2jn9pry, HV_BINOP_MULTIPLY, 1, m, &cBinop_e2jn9pry_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ypFR7Q2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_X3VN1XMk_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_CtQ6vPtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jWv96rd6_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_jWv96rd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_oijSzCj7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qWDMUlP1, m);
}

void Heavy_WSTD_FLANGR::cBinop_oijSzCj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pKkuoUfc, m);
}

void Heavy_WSTD_FLANGR::cMsg_HaRvsX3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JHBzkgsN, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_Sy7AvBKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_RoXHMgkD_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_kG5zwPA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DHiF2Anl_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_asaLjFpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Sy7AvBKm_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_IN1onuSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_avFDkDj9_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_avFDkDj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBBu7BCc, HV_BINOP_MULTIPLY, 1, m, &cBinop_JBBu7BCc_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_DHiF2Anl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_IN1onuSA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_JBBu7BCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_snFRyCtE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_RoXHMgkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBBu7BCc, HV_BINOP_MULTIPLY, 0, m, &cBinop_JBBu7BCc_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_snFRyCtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5eABCtkg, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_LMLfoN8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_lLOExQSQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_lLOExQSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kG5zwPA7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_asaLjFpJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_0K1Uwp4Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CxFOUKH3, 0, m, &cSlice_CxFOUKH3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OjPPYoSq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_CxFOUKH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_h2sMdsWv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_h2sMdsWv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_qXypSg6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h2sMdsWv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_h2sMdsWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PJXvHGDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_OjPPYoSq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CZrkJwSC, 0, m, &cSlice_CZrkJwSC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_T7n8dJv3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_CZrkJwSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HnZAO87b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HnZAO87b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_EaHdqc4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HnZAO87b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_HnZAO87b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6AEv2Adu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_T7n8dJv3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_16IG6Mo5, 0, m, &cSlice_16IG6Mo5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Uhmt00EX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_16IG6Mo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_u5bUbbIP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_u5bUbbIP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_L9bfNIiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_u5bUbbIP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_u5bUbbIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R0N9M0wg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_Uhmt00EX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XlCwbQZC, 0, m, &cSlice_XlCwbQZC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_XlCwbQZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_agB9Ea9d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_agB9Ea9d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_vqiiV6LL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_agB9Ea9d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_agB9Ea9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lwQTCyBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_K6vR6OkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3W5cgtK1, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_6pVYuRyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jKlKujQK, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_FYzJstVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_0K1Uwp4Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_pdYc55mv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_0K1Uwp4Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_2qWxHbBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_0K1Uwp4Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_roD6KZpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_0K1Uwp4Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_eAxrGnq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S6NnOoKo, 0, m, &cVar_S6NnOoKo_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_DaY04Rdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vWnEMdls, 0, m, &cVar_vWnEMdls_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_MSdovjNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iwKN9Wh6, 0, m, &cVar_iwKN9Wh6_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_R0N9M0wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_ti4WaXQT_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_6AEv2Adu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LMLfoN8D_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_1mO0JhpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1SsAd8j3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XyDdSqsH, 0, m, &cVar_XyDdSqsH_sendMessage);
  cMsg_GKug0zQn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FcPWS2dl, 0, m, &cVar_FcPWS2dl_sendMessage);
  cMsg_aIJurtkm_sendMessage(_c, 0, m);
  cMsg_LaSK3rI9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qXypSg6d, 0, m, &cVar_qXypSg6d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EaHdqc4a, 0, m, &cVar_EaHdqc4a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_L9bfNIiK, 0, m, &cVar_L9bfNIiK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vqiiV6LL, 0, m, &cVar_vqiiV6LL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O2n6abgG, 0, m, &cVar_O2n6abgG_sendMessage);
  cMsg_K261rj3U_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_V11cei7y, 0, m, &cVar_V11cei7y_sendMessage);
  cMsg_DOD0gNXV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_lwQTCyBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mUOG4Zqc_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_PJXvHGDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_FRkyREIl_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_MdFUowkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZA34fhpF, 0, m, &cVar_ZA34fhpF_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_O7GSDneY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eAxrGnq2_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_puikHvkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_MSdovjNI_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_MbEGMGXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_DaY04Rdu_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_jKlKujQK, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_ihNFaTFW, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_JHBzkgsN, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_8hFKzdBb, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_VW5AzXvf, VOf(Bf3));
    __hv_rpole_f(&sRPole_JrJKwUh7, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_qWDMUlP1, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_pKkuoUfc, VOf(Bf4));
    __hv_rpole_f(&sRPole_jC5h0ehw, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_n9kM1Rv0, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_HR2Yf9JS, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_40GqeZgQ, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_rJXyaNun, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_rXSyAOQQ, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_cm34hrOX, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_3W5cgtK1, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_cjdlhU1z, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_zXHKrpGf, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_F21hf3A6, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_EHBhblFB, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_FnUAZHjk, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_dzvBNNPx, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_5eABCtkg, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_SqNAgmdu, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_AzuyurUd, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
