/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvControlVar.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvSignalPhasor.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvTable.h"
#include "HvSignalLine.h"
#include "HvSignalTabwrite.h"
#include "HvSignalTabread.h"
#include "HvControlCast.h"
#include "HvSignalDel1.h"
#include "HvSignalRPole.h"
#include "HvControlBinop.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_vWnEMdls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZA34fhpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iwKN9Wh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_S6NnOoKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ti4WaXQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yQuok5Wc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K261rj3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cF4YNxml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O2n6abgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tvP3tKiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i7VJaZAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PBK45go3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GRlIrUTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DOD0gNXV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_edVWNgNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V11cei7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_D7c3Cr1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wwWmo08h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FGqP7kuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M3TQC8Ud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mUOG4Zqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lJma5Kvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Nmim9RxS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CxbcunPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NJH6bO3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qnsIxo7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CWZCgw75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0M6fvIAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sq84qsoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZkEDnuOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yf76ZvZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9awFefHr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zfG2bnYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FRkyREIl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7IdjqlmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aIJurtkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IcFWsYOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kZvEAUle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HtKLzZ16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8pRosjHF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_daBFACUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_gqfhwwMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r1gt1S5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EyzR4Oie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UTxl5Xvx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vV6RYwH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MBppZNTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x8OAOoBK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LaSK3rI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JdtNb23D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YJwCduGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_npGpczk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wTDWQ7vO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_3HnSoCl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_SJPP0jY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xu9KkPJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_APaWWFy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sjryIKbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qGdWRgk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nPkbwlNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_szwGZEV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XyDdSqsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1SsAd8j3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_H8dTisrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZmKZGD45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Qt1azGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rZKEPQHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dsTkxPBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FXObQYKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ioWjoHgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FcPWS2dl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GKug0zQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_F90pXBAu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e2jn9pry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X3VN1XMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ypFR7Q2l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CtQ6vPtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jWv96rd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oijSzCj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HaRvsX3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Sy7AvBKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kG5zwPA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_asaLjFpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IN1onuSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_avFDkDj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DHiF2Anl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JBBu7BCc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RoXHMgkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_snFRyCtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LMLfoN8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLOExQSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0K1Uwp4Y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CxFOUKH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qXypSg6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_h2sMdsWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OjPPYoSq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CZrkJwSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EaHdqc4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HnZAO87b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_T7n8dJv3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_16IG6Mo5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L9bfNIiK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_u5bUbbIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Uhmt00EX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XlCwbQZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vqiiV6LL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_agB9Ea9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K6vR6OkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6pVYuRyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FYzJstVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pdYc55mv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2qWxHbBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_roD6KZpS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eAxrGnq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DaY04Rdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MSdovjNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R0N9M0wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6AEv2Adu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1mO0JhpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lwQTCyBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PJXvHGDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MdFUowkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O7GSDneY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_puikHvkw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MbEGMGXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_jKlKujQK;
  SignalPhasor sPhasor_ihNFaTFW;
  SignalLine sLine_JHBzkgsN;
  SignalRPole sRPole_JrJKwUh7;
  SignalRPole sRPole_jC5h0ehw;
  SignalTabhead sTabhead_n9kM1Rv0;
  SignalTabread sTabread_rXSyAOQQ;
  SignalTabread sTabread_cm34hrOX;
  SignalLine sLine_3W5cgtK1;
  SignalTabhead sTabhead_cjdlhU1z;
  SignalTabread sTabread_FnUAZHjk;
  SignalTabread sTabread_dzvBNNPx;
  SignalLine sLine_5eABCtkg;
  SignalTabwrite sTabwrite_SqNAgmdu;
  SignalTabwrite sTabwrite_AzuyurUd;
  ControlVar cVar_vWnEMdls;
  ControlVar cVar_ZA34fhpF;
  ControlVar cVar_iwKN9Wh6;
  ControlVar cVar_S6NnOoKo;
  ControlBinop cBinop_ti4WaXQT;
  ControlBinop cBinop_yQuok5Wc;
  ControlVar cVar_O2n6abgG;
  ControlBinop cBinop_i7VJaZAw;
  ControlBinop cBinop_GRlIrUTu;
  SignalVarf sVarf_rJXyaNun;
  SignalVarf sVarf_HR2Yf9JS;
  SignalVarf sVarf_40GqeZgQ;
  ControlVar cVar_V11cei7y;
  ControlBinop cBinop_wwWmo08h;
  ControlBinop cBinop_M3TQC8Ud;
  SignalVarf sVarf_EHBhblFB;
  SignalVarf sVarf_zXHKrpGf;
  SignalVarf sVarf_F21hf3A6;
  ControlBinop cBinop_mUOG4Zqc;
  ControlBinop cBinop_lJma5Kvj;
  ControlBinop cBinop_NJH6bO3f;
  ControlBinop cBinop_qnsIxo7I;
  ControlBinop cBinop_Sq84qsoY;
  ControlBinop cBinop_Yf76ZvZ4;
  ControlBinop cBinop_9awFefHr;
  ControlBinop cBinop_zfG2bnYz;
  ControlBinop cBinop_FRkyREIl;
  ControlBinop cBinop_7IdjqlmA;
  ControlDelay cDelay_kZvEAUle;
  ControlDelay cDelay_HtKLzZ16;
  ControlBinop cBinop_daBFACUT;
  HvTable hTable_gqfhwwMa;
  ControlBinop cBinop_EyzR4Oie;
  ControlDelay cDelay_YJwCduGc;
  ControlDelay cDelay_npGpczk7;
  ControlBinop cBinop_3HnSoCl8;
  HvTable hTable_SJPP0jY5;
  ControlBinop cBinop_APaWWFy2;
  ControlVar cVar_XyDdSqsH;
  ControlBinop cBinop_ZmKZGD45;
  ControlBinop cBinop_3Qt1azGW;
  SignalVarf sVarf_VW5AzXvf;
  ControlBinop cBinop_dsTkxPBl;
  ControlBinop cBinop_FXObQYKV;
  ControlBinop cBinop_ioWjoHgp;
  SignalVarf sVarf_8hFKzdBb;
  ControlVar cVar_FcPWS2dl;
  ControlBinop cBinop_e2jn9pry;
  ControlBinop cBinop_X3VN1XMk;
  SignalVarf sVarf_pKkuoUfc;
  ControlBinop cBinop_CtQ6vPtV;
  ControlBinop cBinop_jWv96rd6;
  ControlBinop cBinop_oijSzCj7;
  SignalVarf sVarf_qWDMUlP1;
  ControlBinop cBinop_IN1onuSA;
  ControlBinop cBinop_avFDkDj9;
  ControlBinop cBinop_DHiF2Anl;
  ControlBinop cBinop_JBBu7BCc;
  ControlBinop cBinop_RoXHMgkD;
  ControlBinop cBinop_LMLfoN8D;
  ControlBinop cBinop_lLOExQSQ;
  ControlSlice cSlice_CxFOUKH3;
  ControlVar cVar_qXypSg6d;
  ControlSlice cSlice_CZrkJwSC;
  ControlVar cVar_EaHdqc4a;
  ControlSlice cSlice_16IG6Mo5;
  ControlVar cVar_L9bfNIiK;
  ControlSlice cSlice_XlCwbQZC;
  ControlVar cVar_vqiiV6LL;
  ControlBinop cBinop_eAxrGnq2;
  ControlBinop cBinop_DaY04Rdu;
  ControlBinop cBinop_MSdovjNI;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
